Add a leaf branch to an existing tree tree_old
add_leaf_branch(tree_old, div_t, new_leaf_label, where, position)a "phylo" tree with K+1 leaves
the original "phylo" tree (with K leaves) to which the leaf branch will be added
divergence time of the new branch
the label of the newly added leaf
node name of to which node in the existing tree the new leaf branch should connect to
the numerical location of the left side of the added branch