Learn R Programming

ddtlcm (version 0.2.1)

add_multichotomous_tip: Add a leaf branch to an existing tree tree_old to make a multichotomus branch

Description

Add a leaf branch to an existing tree tree_old to make a multichotomus branch

Usage

add_multichotomous_tip(tree_old, div_t, new_leaf_label, where)

Value

a "phylo" tree with K+1 leaves that could possibly be multichotomus

Arguments

tree_old

the original "phylo" tree (with K leaves) to which the leaf branch will be added

div_t

divergence time of the new branch

new_leaf_label

the label of the newly added leaf

where

node name of to which node in the existing tree the new leaf branch should connect to