Learn R Programming

ddtlcm (version 0.2.1)

data_synthetic: Synthetic data example

Description

This list contains one synthetic data with K = 3 latent classes. The elements are as follows:

Usage

data(data_synthetic)

Arguments

Format

A list with 8 elements

Details

  • tree_phylo. A "phylo" tree with K = 3 leaves.

  • class_probability. A K-vector with entries between 0 and 1.

  • item_membership_list. A list of G = 7 elements, where the g-th element contains the indices of items belonging to major food group g.

  • item_name_list. A list of G = 7 elements, where the g-th element contains the item labels of items in major food group g, and the name of the g-th element is the major food group label.

  • Sigma_by_group. A G-vector greater than 0. The group-specific diffusion variances.

  • response_matrix. A binary matrix with N = 100 rows and J = 80 columns. Each row contains a multivariate binary response vector of a synthetic individual.

  • response_prob. A K by J probability matrix. The k-th row contains the item response probabilities of class k.

  • tree_with_parameter. A phylobase::phylo4d object. Basically the tree_phylo embedded with additional logit(response_prob) at the leaf nodes.