Calculate loglikelihood of a DDT, including the tree structure and node parameters
logllk_ddt(
c,
c_order,
Sigma_by_group,
tree_phylo4d,
item_membership_list,
tree_structure_old = NULL,
dist_mat_old = NULL
)a numeric of loglikelihood
a positive number for the divergence hyperparameter. A larger value implies earlier divergence on the tree
equals 1 if using divergence function a(t) = c / (1-t), or 2 if \(a(t) = c / (1-t)^2\). Default is 1
a vector of diffusion variances of G groups from the previous iteration
a "phylo4d" object
a list of G elements, where the g-th element contains the column
indices of data corresponding to items in major group g
a list of at least named elements: loglikelihoods of the input tree topology and divergence times. These can be directly obtained from the return of this function. Default is NULL. If given a list, then computation of the loglikelihoods will be skipped to save time. This is useful in the Metropolis-Hasting algorithm when the previous proposal is not accepted.
a tree-structured covariance matrix from a given tree. Default is NULL.
Other likelihood functions:
logllk_ddt_lcm(),
logllk_div_time_one(),
logllk_div_time_two(),
logllk_lcm(),
logllk_location(),
logllk_tree_topology()