Calculate loglikelihood of the DDT-LCM
logllk_ddt_lcm(
c,
Sigma_by_group,
tree_phylo4d,
item_membership_list,
tree_structure_old = NULL,
dist_mat_old = NULL,
response_matrix,
leaf_data,
prior_class_probability,
prior_dirichlet,
ClassItem,
Class_count
)a numeric of loglikelihood
a positive number for the divergence hyperparameter. A larger value implies earlier divergence on the tree
a vector of diffusion variances of G groups
a "phylo4d" object
a list of G elements, where the g-th element contains the column
indices of data corresponding to items in major group g
a list of at least named elements: loglikelihoods of the input tree topology and divergence times. These can be directly obtained from the return of this function. Default is NULL. If given a list, then computation of the loglikelihoods will be skipped to save time. This is useful in the Metropolis-Hasting algorithm when the previous proposal is not accepted.
a tree-structured covariance matrix from a given tree. Default is NULL.
a N by J binary matrix, where the i,j-th element is the response of item j for individual i
a K by J matrix of \(logit(theta_kj)\)
a length K vector, where the k-th element is the probability of assigning an individual to class k. It does not have to sum up to 1
a vector of length K. The Dirichlet prior of class probabilities
a K by J matrix, where the k,j-th element counts the number of individuals that belong to class k have a positive response to item j
a length K vector, where the k-th element counts the number of individuals belonging to class k
Other likelihood functions:
logllk_ddt(),
logllk_div_time_one(),
logllk_div_time_two(),
logllk_lcm(),
logllk_location(),
logllk_tree_topology()