Calculate loglikelihood of the latent class model, conditional on tree structure
logllk_lcm(
response_matrix,
leaf_data,
prior_class_probability,
prior_dirichlet,
ClassItem,
Class_count
)a numeric of loglikelihood
a N by J binary matrix, where the i,j-th element is the response of item j for individual i
a K by J matrix of \(logit(theta_{kj})\)
a length K vector, where the k-th element is the probability of assigning an individual to class k. It does not have to sum up to 1
a vector of length K. The Dirichlet prior of class probabilities
a K by J matrix, where the k,j-th element counts the number of individuals that belong to class k have a positive response to item j
a length K vector, where the k-th element counts the number of individuals belonging to class k
Other likelihood functions:
logllk_ddt(),
logllk_ddt_lcm(),
logllk_div_time_one(),
logllk_div_time_two(),
logllk_location(),
logllk_tree_topology()