Compute the marginal log likelihood of the parameters on the leaves of a tree
logllk_location(
tree_phylo4d,
Sigma_by_group,
item_membership_list,
dist_mat = NULL,
tol = 1e-07
)A list of two elements: a numeric loglikelihood, a covariance matrix of the input tree
a "phylo4d" object
a vector of diffusion variances of G groups
a list of G elements, where the g-th element contains the column
indices of data corresponding to items in major group g
a tree-structured covariance matrix from a given tree. Default is NULL. If given a matrix, then computation of the covariance matrix will be skipped to save time. This is useful in the Metropolis-Hasting algorithm when the previous proposal is not accepted.
a small number to prevent underflow when computing eigenvalues
Other likelihood functions:
logllk_ddt(),
logllk_ddt_lcm(),
logllk_div_time_one(),
logllk_div_time_two(),
logllk_lcm(),
logllk_tree_topology()