predict.ddt_lcm: Prediction of class memberships from posterior predictive distributions
Description
Predict individual class memberships based on posterior predictive distributions.
For each posterior sample, let the class memberships be modal assignments. Then aggregate over
all posterior samples to obtain the most likely assigned classes.