Learn R Programming

ddtlcm (version 0.2.1)

summary.ddt_lcm: Summarize the output of a ddt_lcm model

Description

Summarize the output of a ddt_lcm model

Usage

# S3 method for ddt_lcm
summary(object, burnin = 3000, relabel = TRUE, be_quiet = FALSE, ...)

Value

an object of class "summary.ddt_lcm"; a list containing the following elements:

tree_map

the MAP tree of "phylo4d" class

tree_Sigma

the tree-structured covariance matrix associated with tree_map

response_probs_summary, class_probs_summary, Sigma_summary, c_summary

each is a matrix with 7 columns of summary statistics of posterior chains, including means, standard deviation, and five quantiles. In particular, for the summary of item response probabilities, each row name theta_k,g,j represents the response probability of a person in class k to consume item j in group g

max_llk_full

a numeric value of the maximum log-likelihood of the full model (tree and LCM)

max_llk_lcm

a numeric value of the maximum log-likelihood of the LCM only

Z_samples

a N x total_iters integer matrix of posterior samples of individual class assignments

Sigma_by_group_samples

a G x total_iters matrix of posterior samples of diffusion variances

c_samples

a total_iters vector of posterior samples of divergence function hyperparameter

loglikelihood

a total_iters vector of log-likelihoods of the full model

loglikelihood_lcm

a total_iters vector of log-likelihoods of the LCM model only

setting

a list of model setup information. See ddtlcm_fit

controls

a list of model controls. See ddtlcm_fit

data

the input data matrix

Arguments

object

a "ddt_lcm" object

burnin

number of samples to discard from the posterior chain as burn-ins. Default is 3000.

relabel

If TRUE, perform post-hoc label switching using the Equivalence Classes Representatives (ECR) method to solve non-identifiability issue in mixture models. If FALSE, no label switching algorithm will be performed.

be_quiet

If TRUE, do not print information during summarization. If FALSE, print label switching information and model summary.

...

Further arguments passed to each method

See Also

Other ddt_lcm results: print.ddt_lcm(), print.summary.ddt_lcm()

Examples

Run this code
# load the result of fitting semi-synthetic data with 1000 (for the sake of time) posterior samples
data(result_diet_1000iters)
summarized_result <- summary(result_diet_1000iters, burnin = 500, relabel = TRUE, be_quiet = TRUE)

Run the code above in your browser using DataLab