Add a leaf branch to an existing tree tree_old to make a multichotomus branch
add_multichotomous_tip(tree_old, div_t, new_leaf_label, where)a "phylo" tree with K+1 leaves that could possibly be multichotomus
the original "phylo" tree (with K leaves) to which the leaf branch will be added
divergence time of the new branch
the label of the newly added leaf
node name of to which node in the existing tree the new leaf branch should connect to