tree_map
the MAP tree of "phylo4d" class
tree_Sigma
the tree-structured covariance matrix associated with tree_map
response_probs_summary, class_probs_summary, Sigma_summary, c_summary
each is a matrix with 7 columns of summary statistics of posterior chains, including means, standard
deviation, and five quantiles. In particular, for the summary of item response probabilities,
each row name theta_k,g,j represents the response probability of a person in class k to consume item j in group g
max_llk_full
a numeric value of the maximum log-likelihood of the full model (tree and LCM)
max_llk_lcm
a numeric value of the maximum log-likelihood of the LCM only
Z_samples
a N x total_iters integer matrix of posterior samples of individual class assignments
Sigma_by_group_samples
a G x total_iters matrix of posterior samples of diffusion variances
c_samples
a total_iters vector of posterior samples of divergence function hyperparameter
loglikelihood
a total_iters vector of log-likelihoods of the full model
loglikelihood_lcm
a total_iters vector of log-likelihoods of the LCM model only
setting
a list of model setup information. See ddtlcm_fit
controls
a list of model controls. See ddtlcm_fit
data
the input data matrix